@@ -1,13 +1,17 @@
-from IPython.core.display import display, Javascript, HTML
+from IPython.display import display, Javascript, HTML
 import string
 import random
-import pkg_resources
+import importlib.resources
 import urllib.request
 import urllib
 import json
+import sys
 
 
-def display_quiz(ref, num=1_000_000, shuffle_questions=False, shuffle_answers=True, preserve_responses=False):
+
+def display_quiz(ref, num=1_000_000, shuffle_questions=False, shuffle_answers=True, preserve_responses=False,
+                 border_radius=10, question_alignment="left", max_width=600,
+                 colors = None ):
     '''
     Display an interactive quiz (currently multiple-choice or numeric answer)
     using a mix of Python and Javascript to support use in rendered notebooks
@@ -26,9 +30,18 @@ def display_quiz(ref, num=1_000_000, shuffle_questions=False, shuffle_answers=Tr
     shuffle_questions = boolean, whether to shuffle order of questions (default False)
 
     shuffle_answers = boolean, whether to shuffle answers for multiple-choice questions (default True)
-    
+
     preserve_responses = boolean, whether to output the user responses in a way that is preserved upon reload of the notebook (default False)
 
+    border_radius = border radius property for all buttons and questions, in pixels (default 10)
+
+    question_alignment = string, alignment of question text (default "left")
+
+    max_width= number, display width of question in pixels
+
+    colors = None or dict of CSS color names, also takes string 'fdsp' to switch to colors for
+             Foundations of Data Science with Python book
+
     John  M. Shea
     9/26/2021
     '''
@@ -37,8 +50,12 @@ def display_quiz(ref, num=1_000_000, shuffle_questions=False, shuffle_answers=Tr
         "This package does not support preserving responses if questions are shuffled."
     assert num==1_000_000 or (not preserve_responses), \
         "This package does not support preserving responses when num is set because num changes the order of questions"
+    assert question_alignment in ['left', 'right', 'center'], \
+        "question_alignment must be 'left', 'center', or 'right'"
+
 
     resource_package = __name__
+    package = resource_package.split('.')[0]
 
     letters = string.ascii_letters
     div_id = ''.join(random.choice(letters) for i in range(12))
@@ -49,19 +66,69 @@ def display_quiz(ref, num=1_000_000, shuffle_questions=False, shuffle_answers=Tr
     else:
         preserve_json = "false"
 
+    # These are the default colors, but I am working on adding an override
+    # via a argument to display_quiz()
+    color_dict = {
+        '--jq-multiple-choice-bg': '#6f78ffff',
+        '--jq-mc-button-bg': '#fafafa',
+        '--jq-mc-button-border': '#e0e0e0e0',
+        '--jq-mc-button-inset-shadow': '#555555',
+        '--jq-many-choice-bg': '#f75c03ff',
+        '--jq-numeric-bg': '#392061ff',
+        '--jq-numeric-input-bg': '#c0c0c0',
+        '--jq-numeric-input-label': '#101010',
+        '--jq-numeric-input-shadow': '#999999',
+        '--jq-incorrect-color': '#c80202',
+    '--jq-correct-color': '#009113',
+        '--jq-text-color': '#fafafa'
+    }
+    
+    # Colors for Foundations of Data Science with Python
+    #axes.prop_cycle: cycler('color', [ '345995', 'e26d5a', '87a878', '5bc0eb', '861657'])
+    fdsp_dict = {
+        '--jq-multiple-choice-bg': '#345995',
+        '--jq-mc-button-bg': '#fafafa',
+        '--jq-mc-button-border': '#e0e0e0e0',
+        '--jq-mc-button-inset-shadow': '#555555',
+        '--jq-many-choice-bg': '#e26d5a',
+        '--jq-numeric-bg': '#5bc0eb', #'#861657',
+        '--jq-numeric-input-bg': '#c0c0c0',
+        '--jq-numeric-input-label': '#101010',
+        '--jq-numeric-input-shadow': '#999999',
+        '--jq-incorrect-color': '#666666',
+        '--jq-correct-color': '#87a878',
+        '--jq-text-color': '#fafafa'
+    }
 
 
+    # Switch colors if got a dict or 'fdsp' for colors, accordingly
+    if colors == 'fdsp':
+        color_dict = fdsp_dict
+    elif type(colors) == dict:
+        color_dict.update(colors)
+        #print(color_dict)
+
     mydiv = f"""<div id="{div_id}" data-shufflequestions="{str(shuffle_questions)}"
                data-shuffleanswers="{str(shuffle_answers)}"
                data-preserveresponses="{preserve_json}"
-               data-numquestions="{str(num)}"> """
+               data-numquestions="{str(num)}"
+               data-maxwidth="{str(max_width)}"
+               style="border-radius: {str(border_radius)}px; text-align: {question_alignment}"> """
     #print(mydiv)
 
-    styles = "<style>"
-    css = pkg_resources.resource_string(resource_package, "styles.css")
+    styles = "<style>\n"
+    # Now add in the color definitions
+    styles += f'#{div_id}' + ' {\n'
+    for var,color in color_dict.items():
+        styles+=(f'   {var}: {color};\n')
+    styles+= "}\n\n"
+    #print(styles)
+    f = importlib.resources.files(package).joinpath('styles.css')
+    css = f.read_bytes()
     styles += css.decode("utf-8")
     styles += "</style>"
 
+
     script = ''
 
 
@@ -73,7 +140,17 @@ def display_quiz(ref, num=1_000_000, shuffle_questions=False, shuffle_answers=Tr
         url = ""
     elif isinstance(ref, str):
         if ref[0] == '#':
-            script+=f'''var element=document.getElementById("{ref[1:]}");
+            script+=f''' var element=document.getElementById("{ref[1:]}");
+            if (element == null) {{
+               console.log("If you see this mesg on 4.2.5 to 4.3.0, id's don't work -- change to class");
+               var questionTmp = document.getElementsByClassName("{ref[1:]}");
+               // console.log(questionTmp); 
+               element = (questionTmp[0]);
+               //console.log(element);
+            }}
+            if (element == null) {{
+               throw new Error("Could not find element with id or class {ref[1:]}");_
+            }}
             var questions{div_id};
             try {{
                questions{div_id}=JSON.parse(window.atob(element.innerHTML));
@@ -87,9 +164,21 @@ def display_quiz(ref, num=1_000_000, shuffle_questions=False, shuffle_answers=Tr
         elif not ref.lower().find("http"):
             script += f"var questions{div_id}="
             url = ref
-            file = urllib.request.urlopen(url)
-            for line in file:
-                script += line.decode("utf-8")
+            if sys.platform == 'emscripten':
+                try: 
+                    from pyodide.http import open_url
+                except:
+                    try:
+                        from pyodide import open_url
+                    except:
+                        print('Importing open_url failed. Please raise an issue at https://github.com/jmshea/jupyterquiz/issues')
+
+                text = open_url(url).read()
+                script+=text
+            else:
+                file = urllib.request.urlopen(url)
+                for line in file:
+                    script += line.decode("utf-8")
             static = False
         else:
             #print("File detected")
@@ -110,26 +199,50 @@ def display_quiz(ref, num=1_000_000, shuffle_questions=False, shuffle_answers=Tr
     # return
 
     # print(__name__)
-    helpers = pkg_resources.resource_string(resource_package, "helpers.js")
-    script += helpers.decode("utf-8")
+    f = importlib.resources.files(package).joinpath('helpers.js')
+    helpers=f.read_bytes()
+    script += helpers.decode('utf-8')
 
-    multiple_choice = pkg_resources.resource_string(
-        resource_package, "multiple_choice.js")
+    f = importlib.resources.files(package).joinpath('multiple_choice.js')
+    multiple_choice = f.read_bytes()
     script += multiple_choice.decode("utf-8")
 
-    numeric = pkg_resources.resource_string(resource_package, "numeric.js")
+    f = importlib.resources.files(package).joinpath('numeric.js')
+    numeric = f.read_bytes()
     script += numeric.decode("utf-8")
 
-    show_questions = pkg_resources.resource_string(
-        resource_package, "show_questions.js")
+    f = importlib.resources.files(package).joinpath('show_questions.js')
+    show_questions = f.read_bytes()
     script += show_questions.decode("utf-8")
 
+    script += f'''/* This is to handle asynchrony issues in loading Jupyter notebooks
+           where the quiz has been previously run. The Javascript was generally
+           being run before the div was added to the DOM. I tried to do this
+           more elegantly using Mutation Observer, but I didn't get it to work.
+
+           Someone more knowledgeable could make this better ;-) */
+
+        function try_show() {{
+          if(document.getElementById("{div_id}")) {{
+            show_questions(questions{div_id},  {div_id}); 
+          }} else {{
+             setTimeout(try_show, 200);
+          }}
+        }};
+    '''
+
     if static:
         script += f"""
         {{
-        show_questions(questions{div_id},  {div_id});
+        // console.log(element);
+
+        //console.log("{div_id}");
+        // console.log(document.getElementById("{div_id}"));
+
+        try_show();
         }}
         """
+        #print(script)
         javascript = script 
     else:
         script += f'''
