@@ -7,17 +7,15 @@ function check_numeric(ths, event) {
 
         var submission = ths.value;
         if (submission.indexOf('/') != -1) {
-            sub_parts = submission.split('/');
+            var sub_parts = submission.split('/');
             //console.log(sub_parts);
             submission = sub_parts[0] / sub_parts[1];
         }
         //console.log("Reader entered", submission);
 
         if ("precision" in ths.dataset) {
-            precision = ths.dataset.precision;
-            // console.log("1:", submission)
-            submission = Math.round((1 * submission + Number.EPSILON) * 10 ** precision) / 10 ** precision;
-            // console.log("Rounded to ", submission, " precision=", precision  );
+            var precision = ths.dataset.precision;
+            submission = Number(Number(submission).toPrecision(precision));
         }
 
 
@@ -29,10 +27,10 @@ function check_numeric(ths, event) {
         fb.style.display = "none";
         fb.textContent = "Incorrect -- try again.";
 
-        answers = JSON.parse(ths.dataset.answers);
+        var answers = JSON.parse(ths.dataset.answers);
         //console.log(answers);
 
-        var defaultFB = "";
+        var defaultFB = "Incorrect. Try again.";
         var correct;
         var done = false;
         answers.every(answer => {
@@ -42,22 +40,29 @@ function check_numeric(ths, event) {
             // if (answer.type=="value"){
             if ('value' in answer) {
                 if (submission == answer.value) {
-                    fb.textContent = jaxify(answer.feedback);
+                    if ("feedback" in answer) {
+                        fb.innerHTML = jaxify(answer.feedback);
+                    } else {
+                        fb.innerHTML = jaxify("Correct");
+                    }
                     correct = answer.correct;
                     //console.log(answer.correct);
                     done = true;
                 }
                 // } else if (answer.type=="range") {
             } else if ('range' in answer) {
-                //console.log(answer.range);
+                console.log(answer.range);
+                console.log(submission, submission >=answer.range[0], submission < answer.range[1])
                 if ((submission >= answer.range[0]) && (submission < answer.range[1])) {
-                    fb.textContent = jaxify(answer.feedback);
+                    fb.innerHTML = jaxify(answer.feedback);
                     correct = answer.correct;
-                    //console.log(answer.correct);
+                    console.log(answer.correct);
                     done = true;
                 }
             } else if (answer.type == "default") {
-                defaultFB = answer.feedback;
+                if ("feedback" in answer) {
+                    defaultFB = answer.feedback;
+                } 
             }
             if (done) {
                 return false; // Break out of loop if this has been marked correct
@@ -65,6 +70,7 @@ function check_numeric(ths, event) {
                 return true; // Keep looking for case that includes this as a correct answer
             }
         });
+        console.log("done:", done);
 
         if ((!done) && (defaultFB != "")) {
             fb.innerHTML = jaxify(defaultFB);
@@ -126,7 +132,7 @@ function isValid(el, charC) {
         if (el.value.indexOf('.') === -1) {
             return true;
         } else if (el.value.indexOf('/') != -1) {
-            parts = el.value.split('/');
+            var parts = el.value.split('/');
             if (parts[1].indexOf('.') === -1) {
                 return true;
             }
@@ -145,7 +151,7 @@ function isValid(el, charC) {
             return false;
         }
     } else if (charC == 45) {
-        edex = el.value.indexOf('e');
+        var edex = el.value.indexOf('e');
         if (edex == -1) {
             edex = el.value.indexOf('E');
         }
